__author__ = 'tomlun'

import pyglet

import scene
import gamescene

class MainMenuScene(scene.Scene):

    _background = None
    _title = None
    _play = None
    _fullscreen = None
    _exit = None

    _batch = None
    _active_index = 0

    _bg_color_active = (100, 100, 100, 200)
    _bg_color_default = (0, 0, 0, 0)

    def build(self):
        self._batch = pyglet.graphics.Batch()

        self._background = pyglet.sprite.Sprite(
            pyglet.resource.texture('mainmenuscene.png'),
            x=self._scene_manager.get_window_width() / 2 - 160,
            y=self._scene_manager.get_window_height() / 2 - 240,
            batch=self._batch,
            group=pyglet.graphics.OrderedGroup(0)
        )

        self._title = pyglet.text.Label(
            'Hacker Intrusion',
            font_name='wendy',
            font_size=26,
            x=self._scene_manager.get_window_width() / 2,
            y=self._scene_manager.get_window_height() / 2 + 175,
            anchor_x='center', anchor_y='center',
            batch=self._batch,
            group=pyglet.graphics.OrderedGroup(1)
        )

        self._play = pyglet.text.Label(
            ' Play ',
            font_name='wendy',
            font_size=16,
            x=self._scene_manager.get_window_width() / 2,
            y=self._scene_manager.get_window_height() / 2,
            anchor_x='center', anchor_y='center',
            batch=self._batch,
            group=pyglet.graphics.OrderedGroup(1)
        )
        self._play.set_style('background_color', self._bg_color_active)

        self._fullscreen = pyglet.text.Label(
            ' Toggle fullscreen ',
            font_name='wendy',
            font_size=16,
            x=self._scene_manager.get_window_width() / 2,
            y=self._scene_manager.get_window_height() / 2 - 32,
            anchor_x='center', anchor_y='center',
            batch=self._batch,
            group=pyglet.graphics.OrderedGroup(1)
        )

        self._exit = pyglet.text.Label(
            ' Exit ',
            font_name='wendy',
            font_size=16,
            x=self._scene_manager.get_window_width() / 2,
            y=self._scene_manager.get_window_height() / 2 - 64,
            anchor_x='center', anchor_y='center',
            batch=self._batch,
            group=pyglet.graphics.OrderedGroup(1)
        )

    def draw(self):
        self._batch.draw()

    def reset_positions(self):
        self._background.set_position(
            self._scene_manager.get_window_width() / 2 - 160,
            self._scene_manager.get_window_height() / 2 - 240
        )

        self._title.x = self._scene_manager.get_window_width() / 2
        self._title.y = self._scene_manager.get_window_height() / 2 + 175

        self._play.x = self._scene_manager.get_window_width() / 2
        self._play.y = self._scene_manager.get_window_height() / 2

        self._fullscreen.x = self._scene_manager.get_window_width() / 2
        self._fullscreen.y = self._scene_manager.get_window_height() / 2 - 32

        self._exit.x = self._scene_manager.get_window_width() / 2
        self._exit.y = self._scene_manager.get_window_height() / 2 - 64

    def on_key_release(self, symbol, modifiers):
        if symbol == pyglet.window.key.ENTER:
            if self._active_index == 0:
                self._scene_manager.pop_scene()
                self._scene_manager.push_scene(gamescene.GameScene(self._scene_manager))
            if self._active_index == 1:
                self._scene_manager.toggle_window_fullscreen()
                self.reset_positions()
            if self._active_index == 2:
                pyglet.app.exit()

        if symbol == pyglet.window.key.UP:
            self._active_index -= 1
            if self._active_index < 0:
                self._active_index = 0

            if self._active_index == 0:
                self._play.set_style('background_color', self._bg_color_active)
                self._fullscreen.set_style('background_color', self._bg_color_default)
                self._exit.set_style('background_color', self._bg_color_default)
            if self._active_index == 1:
                self._play.set_style('background_color', self._bg_color_default)
                self._fullscreen.set_style('background_color', self._bg_color_active)
                self._exit.set_style('background_color', self._bg_color_default)

        if symbol == pyglet.window.key.DOWN:
            self._active_index += 1
            if self._active_index > 2:
                self._active_index = 2

            if self._active_index == 1:
                self._play.set_style('background_color', self._bg_color_default)
                self._fullscreen.set_style('background_color', self._bg_color_active)
                self._exit.set_style('background_color', self._bg_color_default)
            if self._active_index == 2:
                self._play.set_style('background_color', self._bg_color_default)
                self._fullscreen.set_style('background_color', self._bg_color_default)
                self._exit.set_style('background_color', self._bg_color_active)