__author__ = 'tomlun'

import pyglet


class SceneManager(pyglet.event.EventDispatcher):

    def __init__(self, window):
        pyglet.event.EventDispatcher.__init__(self)
        self.register_event_type('on_pop_scene')
        self._window = window
        self._scenes = []

        self._window.push_handlers(self.draw, self.update)

    def update(self, dt):
        for scene in self._scenes:
            scene.update(dt)

    def draw(self):
        for scene in self._scenes:
            scene.draw()

    def push_scene(self, scene):
        if scene not in self._scenes:
            if len(self._scenes) > 0:
                self._window.pop_handlers()

            self._window.push_handlers(scene.on_key_press, scene.on_key_release)
            self._scenes.append(scene)

    def pop_scene(self):
        self._scenes.pop()
        self._window.pop_handlers()
        if len(self._scenes) > 0:
            self._window.push_handlers(self._scenes[-1].on_key_press, self._scenes[-1].on_key_release)

        self.dispatch_event('on_pop_scene')

    def get_window_width(self):
        return self._window.width

    def get_window_height(self):
        return self._window.height

    def toggle_window_fullscreen(self):
        if self._window.fullscreen:
            self._window.set_fullscreen(False)
        else:
            self._window.set_fullscreen(True)


class Scene(object):

    def __init__(self, scene_manager):
        self._scene_manager = scene_manager
        self.build()

    def build(self):
        pass

    def update(self, dt):
        pass

    def draw(self):
        pass

    def on_key_press(self, symbol, modifiers):
        pass

    def on_key_release(self, symbol, modifiers):
        pass