__author__ = 'tomlun'

import pyglet

TILE_SIZE = 64

# Tile types
_FLOOR = 0
_WALL = 1
_EMPTY = 9


def create_tile(tile_type, x, y, batch):
    if tile_type == _FLOOR:
        return Floor(x * TILE_SIZE, y * TILE_SIZE, batch)
    if tile_type == _WALL:
        return Wall(x * TILE_SIZE, y * TILE_SIZE, batch)
    if tile_type == _EMPTY:
        return Empty(x * TILE_SIZE, y * TILE_SIZE, batch)


class Tile(pyglet.sprite.Sprite):

    _image = None
    _blocking = None

    def __init__(self, x, y, batch):
        pyglet.sprite.Sprite.__init__(self, self._image, x, y, batch=batch)
        self.opacity = 100

    def is_blocking(self):
        return self._blocking

    def is_lit(self):
        return self.opacity == 200

    def lit(self):
        self.opacity = 200

    def unlit(self):
        self.opacity = 100


class Empty(Tile):
    _image = pyglet.image.SolidColorImagePattern().create_image(TILE_SIZE, TILE_SIZE)


class Floor(Tile):
    _image = pyglet.resource.texture('floor.png')
    _blocking = False


class Wall(Tile):
    _image = pyglet.resource.texture('wall.png')
    _blocking = True
